@@ -4,4 +4,7 @@ import sys
 try:
     cmdfile.run(sys.argv[1], filename=sys.argv[2])
 except:
-    cmdfile.run(sys.argv[1])
\ No newline at end of file
+    try:
+        cmdfile.run(sys.argv[1])
+    except:
+        cmdfile.run()
\ No newline at end of file
